[prev in list] [next in list] [prev in thread] [next in thread] 

List:       openvas-cvs
Subject:    [Openvas-commits] r6285 - in trunk/openvas-libraries: . omp
From:       scm-commit () wald ! intevation ! org
Date:       2009-12-30 19:47:33
Message-ID: 20091230194733.271EB865F467 () pyrosoma ! intevation ! org
[Download RAW message or body]

Author: mattm
Date: 2009-12-30 20:47:31 +0100 (Wed, 30 Dec 2009)
New Revision: 6285

Modified:
   trunk/openvas-libraries/ChangeLog
   trunk/openvas-libraries/omp/omp.c
   trunk/openvas-libraries/omp/omp.h
Log:
	* omp/omp.c (omp_create_lsc_credential): Add login arg for updated OMP.

	* omp/omp.h: Update header accordingly.

Modified: trunk/openvas-libraries/ChangeLog
===================================================================
--- trunk/openvas-libraries/ChangeLog	2009-12-30 19:12:40 UTC (rev 6284)
+++ trunk/openvas-libraries/ChangeLog	2009-12-30 19:47:31 UTC (rev 6285)
@@ -1,3 +1,9 @@
+2009-12-30  Matthew Mundell <matthew.mundell@intevation.de>
+
+	* omp/omp.c (omp_create_lsc_credential): Add login arg for updated OMP.
+
+	* omp/omp.h: Update header accordingly.
+
 2009-12-23  Felix Wolfsteller <felix.wolfsteller@intevation.de>
 
 	* misc/scanners_utils.h: Copied header of implementation file to

Modified: trunk/openvas-libraries/omp/omp.c
===================================================================
--- trunk/openvas-libraries/omp/omp.h	2009-12-30 19:12:40 UTC (rev 6284)
+++ trunk/openvas-libraries/omp/omp.h	2009-12-30 19:47:31 UTC (rev 6285)
@@ -143,7 +143,8 @@
 omp_delete_config (gnutls_session_t*, const char*);
 
 int
-omp_create_lsc_credential (gnutls_session_t*, const char*, const char*);
+omp_create_lsc_credential (gnutls_session_t*, const char*, const char*,
+                           const char*);
 
 int
 omp_delete_lsc_credential (gnutls_session_t*, const char*);

_______________________________________________
Openvas-commits mailing list
Openvas-commits@wald.intevation.org
http://lists.wald.intevation.org/mailman/listinfo/openvas-commits
[prev in list] [next in list] [prev in thread] [next in thread] 

Configure | About | News | Add a list | Sponsored by KoreLogic
--- trunk/openvas-libraries/omp/omp.c	2009-12-30 19:12:40 UTC (rev 6284)
+++ trunk/openvas-libraries/omp/omp.c	2009-12-30 19:47:31 UTC (rev 6285)
@@ -1572,15 +1572,17 @@
 /**
  * @brief Create an LSC Credential.
  *
  * @param[in]   session     Pointer to GNUTLS session.
  * @param[in]   name        Name of LSC Credential.
  * @param[in]   comment     LSC Credential comment.
  *
  * @return 0 on success, -1 on error.
  */
 int
 omp_create_lsc_credential (gnutls_session_t* session,
                            const char* name,
+                           const char* login,
                            const char* comment)
 {
   int ret;
@@ -1591,15 +1593,19 @@
   if (comment)
     new_task_request = g_strdup_printf ("<create_lsc_credential>"
                                         "<name>%s</name>"
+                                        "<login>%s</login>"
                                         "<comment>%s</comment>"
                                         "</create_lsc_credential>",
                                         name,
+                                        login,
                                         comment);
   else
     new_task_request = g_strdup_printf ("<create_lsc_credential>"
                                         "<name>%s</name>"
+                                        "<login>%s</login>"
                                         "</create_lsc_credential>",
-                                        name);
+                                        name,
+                                        login);
 
   /* Send the request. */
 
@@ -1572,15 +1572,17 @@
  * @brief Create an LSC Credential.
  *
- * @param[in]   session     Pointer to GNUTLS session.
- * @param[in]   name        Name of LSC Credential.
- * @param[in]   comment     LSC Credential comment.
+ * @param[in]   session  Pointer to GNUTLS session.
+ * @param[in]   name     Name of LSC Credential.
+ * @param[in]   login    Login associated with name.
+ * @param[in]   comment  LSC Credential comment.
  *
  * @return 0 on success, -1 on error.

Modified: trunk/openvas-libraries/omp/omp.h
===================================================================